Overview
========

Allows data from FITS files to be imported into Tensorflow 2.x's 
`td.data.Dataset`. Requires Tensorflow 2.x's `tf.io.read_file` to read in the 
data from the FITS file as a binary string and then provides methods to decode 
the binary string into usable data following the FITS format.

**Authors**

 - William J. Pearson

**Disclaimer**

This package and the package's author are not affiliated with Tensorflow or 
Google or Alphabet.

**Licensing**

Licensed under Apache-2.0
